``zope.traversing``
===================

.. image:: https://travis-ci.org/zopefoundation/zope.traversing.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.traversing

This package provides adapters for resolving object paths by traversing
an object hierarchy.  This package also includes support for traversal
namespaces (e.g. ``++view++``, ``++skin++``, etc.) as well as computing
URLs via the ``@@absolute_url`` view.
